@@ -50,8 +50,8 @@ extern const char * const bitset_type_names[];
 enum bitset_alloc_type {BITSET_MALLOC, BITSET_OBALLOC};
 
 /* Data type used to store a word of bits.  */
-typedef unsigned long int bitset_word;
-#define BITSET_WORD_BITS ((unsigned int) (CHAR_BIT * sizeof (bitset_word)))
+typedef unsigned long bitset_word;
+#define BITSET_WORD_BITS ((unsigned) (CHAR_BIT * sizeof (bitset_word)))
 
 /* Bit index.  In theory we might need a type wider than size_t, but
    in practice we lose at most a factor of CHAR_BIT by going with
@@ -281,24 +281,24 @@ if (!BITSET_COMPATIBLE_ (DST, SRC1) || !BITSET_COMPATIBLE_ (DST, SRC2) \
 
 /* Private functions for bitset implementations.  */
 
-extern bool bitset_toggle_ (bitset, bitset_bindex);
+bool bitset_toggle_ (bitset, bitset_bindex);
 
-extern bitset_bindex bitset_count_ (bitset);
+bitset_bindex bitset_count_ (bitset);
 
-extern bitset_bindex bitset_size_ (bitset);
+bitset_bindex bitset_size_ (bitset);
 
-extern bool bitset_copy_ (bitset, bitset);
+bool bitset_copy_ (bitset, bitset);
 
-extern void bitset_and_or_ (bitset, bitset, bitset, bitset);
+void bitset_and_or_ (bitset, bitset, bitset, bitset);
 
-extern bool bitset_and_or_cmp_ (bitset, bitset, bitset, bitset);
+bool bitset_and_or_cmp_ (bitset, bitset, bitset, bitset);
 
-extern void bitset_andn_or_ (bitset, bitset, bitset, bitset);
+void bitset_andn_or_ (bitset, bitset, bitset, bitset);
 
-extern bool bitset_andn_or_cmp_ (bitset, bitset, bitset, bitset);
+bool bitset_andn_or_cmp_ (bitset, bitset, bitset, bitset);
 
-extern void bitset_or_and_ (bitset, bitset, bitset, bitset);
+void bitset_or_and_ (bitset, bitset, bitset, bitset);
 
-extern bool bitset_or_and_cmp_ (bitset, bitset, bitset, bitset);
+bool bitset_or_and_cmp_ (bitset, bitset, bitset, bitset);
 
 #endif /* _BBITSET_H  */
